#pragma once

/*
 * Copyright (C) 2014-2015 Achim Turan, Achim.Turan@o2online.de
 * https://github.com/AchimTuran/asplib
 *
 * This file is part of asplib (Achim's Signal Processing LIBrary)
 *
 * asplib (Achim's Signal Processing LIBrary) is free software:
 * you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation,
 * either version 3 of the License, or (at your option) any later version.
 *
 * asplib (Achim's Signal Processing LIBrary) is distributed
 * in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with asplib (Achim's Signal Processing LIBrary).
 * ifnot, see <http://www.gnu.org/licenses/>.
 *
 */



//negative exponents
#define E_m3     1.0e-3f       //m
#define E_m6     1.0e-6f       //u
#define E_m9     1.0e-9f       //n
#define E_m12    1.0e-12f      //p
#define E_m15    1.0e-15f      //f

//positive exponents
#define E_p3     1.0e3f        //k
#define E_p6     1.0e6f        //Meg
#define E_p9     1.0e9f        //Gig
#define E_p12    1.0e12f       //T
#define E_p15    1.0e15f       //
